import { InjectionToken, Component, ElementRef, Input, Inject, Optional, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import CodeMirror from 'codemirror';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const WA_CODEMIRROR_DEFAULTS = new InjectionToken('WA_CODEMIRROR_DEFAULTS');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CodemirrorComponent {
    /**
     * @param {?} $el
     * @param {?} defaults
     */
    constructor($el, defaults) {
        this.$el = $el;
        this.onChange = (_) => { };
        this.onTouched = () => { };
        this.defaults = defaults || {};
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        const /** @type {?} */ config = Object.assign({}, this.defaults);
        if (typeof this.lineNumbers !== 'undefined') {
            config.lineNumbers = this.lineNumbers;
        }
        if (typeof this.mode !== 'undefined') {
            config.mode = this.mode;
        }
        if (typeof this.theme !== 'undefined') {
            config.theme = this.theme;
        }
        if (typeof this.defaultValue !== 'undefined') {
            config.value = this.defaultValue;
        }
        this.codemirror = CodeMirror(this.$el.nativeElement, config);
        this.codemirror.on('change', (editor) => {
            this.onChange(editor.getValue());
        });
        this.codemirror.on('blur', () => {
            this.onTouched();
        });
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        if (this.codemirror) {
            this.codemirror.setValue(value);
        }
        else {
            this.defaultValue = value;
        }
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
}
CodemirrorComponent.decorators = [
    { type: Component, args: [{
                selector: 'wa-codemirror',
                template: '',
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: CodemirrorComponent,
                        multi: true,
                    },
                ],
            },] },
];
/** @nocollapse */
CodemirrorComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: undefined, decorators: [{ type: Inject, args: [WA_CODEMIRROR_DEFAULTS,] }, { type: Optional },] },
];
CodemirrorComponent.propDecorators = {
    "mode": [{ type: Input },],
    "theme": [{ type: Input },],
    "lineNumbers": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CodemirrorModule {
}
CodemirrorModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    CodemirrorComponent,
                ],
                exports: [
                    CodemirrorComponent,
                ],
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { CodemirrorComponent, CodemirrorModule, WA_CODEMIRROR_DEFAULTS };
//# sourceMappingURL=webacad-ng-codemirror.js.map
